/*	$Id: hash.c,v 1.2 2002/01/04 22:55:19 wouter Exp $	*/

/*
 * hash.c - simple hash table management
 * Copyright (C) Wouter Coene, 2001, 2002
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
 * THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/*
 * This code is modelled after a quadratic probing hash table in JAVA made
 * by Mark Allen Weiss.
 */

#include "hash.h"

/***
 * hash_nextprime --
 *	Find a prime number at least as large as the given number.
 *
 * Arguments:
 *	num	The number to start at for primality testing
 * Returns:
 *	A prime number larger than or equal to num.
 */
int hash_nextprime(int num)
{
	int i;

	/* primes are always odd */
	if (num%2==0)
		num++;

	/* sloppy algorithm to look for primes */
	for (;; num+=2) {
		if ((num==2) || (num==3))
			break;

		if ((num==1) || (num%2==0))
			goto not_prime;			/* juch */

		for (i=3; i*i<=num; i+=2)
			if (num%i==0)
				goto not_prime;		/* puke */

		break;
not_prime:
	}

	return num;
}

/* end hash.c */
